@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Cmd::Publisher::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::Cmd::Publisher::VERSION = '0.102';
+  $App::DuckPAN::Cmd::Publisher::VERSION = '0.103';
 }
 # ABSTRACT: Starting up the publisher test webserver
 
@@ -15,6 +15,14 @@ use MooX::Options;
 use Path::Class;
 use Plack::Handler::Starman;
 
+for (qw( duckduckgo dontbubbleus donttrackus whatisdnt fixtracking )) {
+	option $_ => (
+		is => 'ro',
+		format => 's',
+		predicate => 1,
+	);
+}
+
 sub run {
 	my ( $self, @args ) = @_;
 
@@ -30,24 +38,24 @@ sub run {
 	my %sites = (
 		duckduckgo => {
 			port => 5000,
-			url => "http://duckduckgo.com/",
+			url => $self->has_duckduckgo ? $self->duckduckgo : "http://duckduckgo.com/",
 		},
 		dontbubbleus => {
 			port => 5001,
-			url => "http://dontbubble.us/",
+			url => $self->has_dontbubbleus ? $self->dontbubbleus : "http://dontbubble.us/",
 		},
 		donttrackus => {
 			port => 5002,
-			url => "http://donttrack.us/",
+			url => $self->has_donttrackus ? $self->donttrackus : "http://donttrack.us/",
 		},	
 		whatisdnt => {
 			port => 5003,
-			url => "http://whatisdnt.com/",
+			url => $self->has_whatisdnt ? $self->whatisdnt : "http://whatisdnt.com/",
+		},
+		fixtracking => {
+			port => 5004,
+			url => $self->has_fixtracking ? $self->fixtracking : "http://fixtracking.com/",
 		},
-		#fixtracking => {
-		#	port => 5004,
-		#	url => "http://fixtracking.com/",
-		#},
 	);
 
 	for (keys %sites) {
@@ -76,7 +84,7 @@ App::DuckPAN::Cmd::Publisher - Starting up the publisher test webserver
 
 =head1 VERSION
 
-version 0.102
+version 0.103
 
 =head1 AUTHOR
 
